StreamingEngine

Struct StreamingEngine 

pub struct StreamingEngine { /* private fields */ }
The main streaming engine for pub/sub and CDC.

Implementations

Source

impl StreamingEngine

pub fn new() -> Self

Create a new streaming engine.

pub fn with_config(config: EngineConfig) -> Self

Create an engine with custom configuration.

pub fn create_channel( &self, id: impl Into<ChannelId>, ) -> Result<(), EngineError>

Create a new channel.

pub fn create_channel_with_config( &self, id: impl Into<ChannelId>, config: ChannelConfig, ) -> Result<(), EngineError>

Create a channel with custom configuration.

pub fn delete_channel(&self, id: &ChannelId) -> Result<(), EngineError>

Delete a channel.

pub fn list_channels(&self) -> Vec<ChannelId>

List all channels.

pub fn channel_exists(&self, id: &ChannelId) -> bool

Check if a channel exists.

pub fn publish( &self, channel_id: &ChannelId, event: Event, ) -> Result<usize, EngineError>

Publish an event to a channel.

pub fn publish_change( &self, channel_id: &ChannelId, change: ChangeEvent, ) -> Result<usize, EngineError>

Publish a CDC change event.

pub fn publish_to_many( &self, channel_ids: &[ChannelId], event: Event, ) -> HashMap<ChannelId, Result<usize, EngineError>>

Publish to multiple channels.

pub fn subscribe( &self, channel_id: &ChannelId, subscriber_id: impl Into<SubscriberId>, ) -> Result<ChannelReceiver, EngineError>

Subscribe to a channel.

pub fn subscribe_with_filter( &self, channel_id: &ChannelId, subscriber_id: impl Into<SubscriberId>, filter: EventFilter, ) -> Result<ChannelReceiver, EngineError>

Subscribe with a filter.

pub fn unsubscribe(&self, channel_id: &ChannelId, subscriber_id: &SubscriberId)

Unsubscribe from a channel.

pub fn get_subscriber(&self, id: &SubscriberId) -> Option<Subscriber>

Get a subscriber.

pub fn list_subscribers(&self) -> Vec<SubscriberId>

List all subscribers.

pub fn remove_subscriber(&self, id: &SubscriberId)

Remove a subscriber.

pub fn create_consumer_group( &self, group_id: impl Into<String>, ) -> Result<(), EngineError>

Create a new consumer group with the given ID.

pub fn delete_consumer_group(&self, group_id: &str) -> Result<(), EngineError>

Delete a consumer group.

pub fn join_consumer_group( &self, group_id: &str, subscriber_id: SubscriberId, channels: HashSet<String>, ) -> Result<(), EngineError>

Join a consumer group. The subscriber is added as a member with the given set of assigned channels.

pub fn leave_consumer_group( &self, group_id: &str, subscriber_id: &SubscriberId, ) -> Result<HashSet<String>, EngineError>

Leave a consumer group. Returns the channels that were assigned to the subscriber, or an error if the group or member was not found.

pub fn commit_offset( &self, group_id: &str, channel_name: impl Into<String>, offset: u64, ) -> Result<(), EngineError>

Commit an offset for a channel within a consumer group.

pub fn get_committed_offset( &self, group_id: &str, channel_name: &str, ) -> Result<Option<u64>, EngineError>

Get the committed offset for a channel within a consumer group.

pub fn list_consumer_groups(&self) -> Vec<String>

List all consumer groups.

pub fn get_consumer_group(&self, group_id: &str) -> Option<ConsumerGroup>

Get a snapshot of a consumer group.

pub fn get_history( &self, channel_id: &ChannelId, count: usize, ) -> Result<Vec<Event>, EngineError>

Get recent events from a channel.

pub fn get_history_after( &self, channel_id: &ChannelId, timestamp: u64, ) -> Result<Vec<Event>, EngineError>

Get events after a timestamp.

pub fn stats(&self) -> EngineStats

Get engine statistics.

pub fn reset_stats(&self)

Reset statistics.

pub fn channel_stats(&self, id: &ChannelId) -> Option<ChannelStats>

Get channel statistics.